#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/dialog.d/OWNCLOUD_DB_TYPE.sh
#
# Copyright (c) 2012-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2012-12-20  jed
# Last Update:  $Id: OWNCLOUD_DB_TYPE.sh 71801 2020-01-05 09:58:48Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

. /var/install/include/cuilib
. /var/install/include/ecelib

pgmname=`basename $0`
module_name="`echo "${pgmname}" | cut -d_ -f1 | tr '[:upper:]' '[:lower:]'`"

#----------------------------------------------------------------------------
# exec_dailog
# ece --> request to create and execute dialog
#         $p2 --> main window handle
#         $p3 --> name of config variable
#----------------------------------------------------------------------------
exec_dialog()
{
    win="$p2"

    # SQLite
    sellist='sqlite'

    # MySQL/MariaDB - sellist="sqlite,mssql,mysql,mysqli,pgsql,sqlsrv"
    my_count=`{
                /usr/bin/eisman search --fields=name --installed "mariadb"
                /usr/bin/eisman search --fields=name --installed "mysql"
              } | grep -v "^\-----" | sed 's/^name *//' | grep -E "^mariadb$|^mariadb[0-9]+$|^mysql$|^mysql[0-9]+" | wc -l`

    if [ ${my_count} -gt 0 ]
    then
        sellist="${sellist},mysql"
    fi

    # PostgreSQL
    if [ "`/usr/bin/eisman check postgresql`" = 'installed' ]
    then
        sellist="${sellist},pgsql"
    fi

    # check if a selection has previously been made
    if [ -z "${value}" ]
    then
        # empty, set to default value
        value='sqlite'
    fi

    # check if pre-configured value is still valid
    echo ",${sellist}," | grep -q ",${value},"

    if [ $? -ne 0 ]
    then
        # not found, set to default value
        value='sqlite'
    fi

    ece_select_list_dlg "${win}" "Database type" "${sellist}"
}

#----------------------------------------------------------------------------
# main routine
#----------------------------------------------------------------------------

cui_init
cui_run

#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------

exit 0
